@@ -143,6 +143,31 @@ static uint32_t rc_scale_value(uint32_t value, uint8_t oper, const rc_operand_t*
     case RC_OPERATOR_XOR:
       return value | rc_max_value(operand);
 
+    case RC_OPERATOR_MOD:
+    {
+      const uint32_t divisor = (operand->type == RC_OPERAND_CONST) ? operand->value.num : 1;
+      return (divisor >= value) ? (divisor - 1) : value;
+    }
+
+    case RC_OPERATOR_ADD:
+    {
+      unsigned long scaled = ((unsigned long)value) + rc_max_value(operand);
+      if (scaled > 0xFFFFFFFF)
+        return 0xFFFFFFFF;
+
+      return (uint32_t)scaled;
+    }
+
+    case RC_OPERATOR_SUB:
+    {
+      if (operand->type == RC_OPERAND_CONST)
+        return value - operand->value.num;
+      else if (value > rc_max_value(operand))
+        return value - rc_max_value(operand);
+
+      return 0xFFFFFFFF;
+    }
+
     default:
       return value;
   }
@@ -241,6 +266,8 @@ int rc_validate_condset_internal(const rc_condset_t* condset, char result[], con
   int in_add_hits = 0;
   int in_add_address = 0;
   int is_combining = 0;
+  int remember_used = 0;
+  int remember_used_in_pause = 0;
 
   if (!condset) {
     *result = '\0';
@@ -251,6 +278,7 @@ int rc_validate_condset_internal(const rc_condset_t* condset, char result[], con
     uint32_t max = rc_max_value(&cond->operand1);
     const int is_memref1 = rc_operand_is_memref(&cond->operand1);
     const int is_memref2 = rc_operand_is_memref(&cond->operand2);
+    const int uses_recall = rc_operand_is_recall(&cond->operand1) || rc_operand_is_recall(&cond->operand2);
 
     if (!in_add_address) {
       if (is_memref1 && !rc_validate_memref(cond->operand1.value.memref, buffer, sizeof(buffer), console_id, max_address)) {
@@ -266,6 +294,28 @@ int rc_validate_condset_internal(const rc_condset_t* condset, char result[], con
       in_add_address = 0;
     }
 
+    if (!remember_used && uses_recall) {
+      if (!cond->pause && condset->has_pause) {
+        /* pause conditions will be processed before non-pause conditions.
+         * scan forward for any remembers in yet-to-be-processed pause conditions */
+        const rc_condition_t* cond_rem_pause_check = cond->next;
+        for (; cond_rem_pause_check; cond_rem_pause_check = cond_rem_pause_check->next) {
+          if (cond_rem_pause_check->type == RC_CONDITION_REMEMBER && cond_rem_pause_check->pause) {
+            remember_used = 1; /* do not set remember_used_in_pause here because we don't know at which poing in the pause processing this remember is occurring. */
+            break;
+          }
+        }
+      }
+      if (!remember_used) {
+        snprintf(result, result_size, "Condition %d: Recall used before Remember", index);
+        return 0;
+      }
+    }
+    else if (cond->pause && uses_recall && !remember_used_in_pause) {
+      snprintf(result, result_size, "Condition %d: Recall used in Pause processing before Remember was used in Pause processing", index);
+      return 0;
+    }
+
     switch (cond->type) {
       case RC_CONDITION_ADD_SOURCE:
         max = rc_scale_value(max, cond->oper, &cond->operand2);
@@ -289,6 +339,12 @@ int rc_validate_condset_internal(const rc_condset_t* condset, char result[], con
         is_combining = 1;
         continue;
 
+      case RC_CONDITION_REMEMBER:
+        is_combining = 1;
+        remember_used = 1;
+        remember_used_in_pause += cond->pause;
+        continue;
+
       case RC_CONDITION_ADD_HITS:
       case RC_CONDITION_SUB_HITS:
         in_add_hits = 1;
@@ -435,6 +491,7 @@ static int rc_validate_is_combining_condition(const rc_condition_t* condition)
     case RC_CONDITION_RESET_NEXT_IF:
     case RC_CONDITION_SUB_HITS:
     case RC_CONDITION_SUB_SOURCE:
+    case RC_CONDITION_REMEMBER:
       return 1;
 
     default:
@@ -442,22 +499,6 @@ static int rc_validate_is_combining_condition(const rc_condition_t* condition)
   }
 }
 
-static const rc_condition_t* rc_validate_next_non_combining_condition(const rc_condition_t* condition)
-{
-  int is_combining = rc_validate_is_combining_condition(condition);
-  for (condition = condition->next; condition != NULL; condition = condition->next)
-  {
-    if (rc_validate_is_combining_condition(condition))
-      is_combining = 1;
-    else if (is_combining)
-      is_combining = 0;
-    else
-      return condition;
-  }
-
-  return NULL;
-}
-
 static int rc_validate_get_opposite_comparison(int oper)
 {
   switch (oper)
@@ -656,6 +697,24 @@ static int rc_validate_comparison_overlap(int comparison1, uint32_t value1, int
   return RC_OVERLAP_NONE;
 }
 
+static int rc_validate_are_operands_equal(const rc_operand_t* oper1, const rc_operand_t* oper2)
+{
+  if (oper1->type != oper2->type)
+    return 0;
+
+  switch (oper1->type)
+  {
+  case RC_OPERAND_CONST:
+    return (oper1->value.num == oper2->value.num);
+  case RC_OPERAND_FP:
+    return (oper1->value.dbl == oper2->value.dbl);
+  case RC_OPERAND_RECALL:
+    return (oper2->type == RC_OPERAND_RECALL);
+  default:
+    return (oper1->value.memref->address == oper2->value.memref->address && oper1->size == oper2->size);
+  }
+}
+
 static int rc_validate_conflicting_conditions(const rc_condset_t* conditions, const rc_condset_t* compare_conditions,
     const char* prefix, const char* compare_prefix, char result[], const size_t result_size)
 {
@@ -665,16 +724,23 @@ static int rc_validate_conflicting_conditions(const rc_condset_t* conditions, co
   const rc_operand_t* operand2;
   const rc_condition_t* compare_condition;
   const rc_condition_t* condition;
+  const rc_condition_t* condition_chain_start;
   int overlap;
+  int chain_matches;
 
   /* empty group */
   if (conditions == NULL || compare_conditions == NULL)
     return 1;
 
   /* outer loop is the source conditions */
-  for (condition = conditions->conditions; condition != NULL;
-      condition = rc_validate_next_non_combining_condition(condition))
+  for (condition = conditions->conditions; condition != NULL; condition = condition->next)
   {
+    condition_chain_start = condition;
+    while (rc_condition_is_combining(condition))
+      condition = condition->next;
+    if (!condition)
+      break;
+
     /* hits can be captured at any time, so any potential conflict will not be conflicting at another time */
     if (condition->required_hits)
       continue;
@@ -699,11 +765,69 @@ static int rc_validate_conflicting_conditions(const rc_condset_t* conditions, co
     }
 
     /* inner loop is the potentially conflicting conditions */
-    for (compare_condition = compare_conditions->conditions; compare_condition != NULL;
-        compare_condition = rc_validate_next_non_combining_condition(compare_condition))
+    for (compare_condition = compare_conditions->conditions; compare_condition != NULL; compare_condition = compare_condition->next)
     {
-      if (compare_condition == condition)
+      if (compare_condition == condition_chain_start)
+      {
+        /* skip condition we're already looking at */
+        while (compare_condition != condition)
+          compare_condition = compare_condition->next;
+
         continue;
+      }
+
+      /* if combining conditions exist, make sure the same combining conditions exist in the
+       * compare logic. conflicts can only occur if the combinining conditions match. */
+      chain_matches = 1;
+      if (condition_chain_start != condition)
+      {
+        const rc_condition_t* condition_chain_iter = condition_chain_start;
+        while (condition_chain_iter != condition)
+        {
+          if (compare_condition->type != condition_chain_iter->type ||
+            compare_condition->oper != condition_chain_iter->oper ||
+            compare_condition->required_hits != condition_chain_iter->required_hits ||
+            !rc_validate_are_operands_equal(&compare_condition->operand1, &condition_chain_iter->operand1))
+          {
+            chain_matches = 0;
+            break;
+          }
+
+          if (compare_condition->oper != RC_OPERATOR_NONE &&
+            !rc_validate_are_operands_equal(&compare_condition->operand2, &condition_chain_iter->operand2))
+          {
+            chain_matches = 0;
+            break;
+          }
+
+          if (!compare_condition->next)
+          {
+            chain_matches = 0;
+            break;
+          }
+
+          if (compare_condition->type != RC_CONDITION_ADD_ADDRESS &&
+              compare_condition->type != RC_CONDITION_ADD_SOURCE &&
+              compare_condition->type != RC_CONDITION_SUB_SOURCE &&
+              compare_condition->type != RC_CONDITION_AND_NEXT)
+          {
+            /* things like AddHits and OrNext are hard to definitively detect conflicts. ignore them. */
+            chain_matches = 0;
+            break;
+          }
+
+          compare_condition = compare_condition->next;
+          condition_chain_iter = condition_chain_iter->next;
+        }
+      }
+
+      /* combining field didn't match, or there's more unmatched combining fields. ignore this condition */
+      if (!chain_matches || rc_validate_is_combining_condition(compare_condition))
+      {
+        while (compare_condition->next && rc_validate_is_combining_condition(compare_condition))
+          compare_condition = compare_condition->next;
+        continue;
+      }
 
       if (compare_condition->required_hits)
         continue;
