@@ -384,6 +384,95 @@ static void test_process_fetch_game_data_response_achievement_rarity() {
   rc_api_destroy_fetch_game_data_response(&fetch_game_data_response);
 }
 
+
+static void test_process_fetch_game_data_response_achievement_null_author()
+{
+  rc_api_fetch_game_data_response_t fetch_game_data_response;
+  const char* server_response = "{\"Success\":true,\"PatchData\":{"
+    "\"ID\":20,\"Title\":\"Another Amazing Game\",\"ConsoleID\":19,\"ImageIcon\":\"/Images/112233.png\","
+    "\"Achievements\":["
+    "{\"ID\":5501,\"Title\":\"Ach1\",\"Description\":\"Desc1\",\"Flags\":3,\"Points\":5,"
+    "\"MemAddr\":\"0=1\",\"Author\":\"User1\",\"BadgeName\":\"00234\","
+    "\"Created\":1367266583,\"Modified\":1376929305},"
+    "{\"ID\":5502,\"Title\":\"Ach2\",\"Description\":\"Desc2\",\"Flags\":3,\"Points\":2,"
+    "\"MemAddr\":\"0=2\",\"Author\":null,\"BadgeName\":\"00235\","
+    "\"Created\":1376970283,\"Modified\":1376970283},"
+    "{\"ID\":5503,\"Title\":\"Ach3\",\"Description\":\"Desc3\",\"Flags\":5,\"Points\":0,"
+    "\"MemAddr\":\"0=3\",\"Author\":null,\"BadgeName\":\"00236\","
+    "\"Created\":1376969412,\"Modified\":1376969412},"
+    "{\"ID\":5504,\"Title\":\"Ach4\",\"Description\":\"Desc4\",\"Flags\":3,\"Points\":10,"
+    "\"MemAddr\":\"0=4\",\"Author\":\"User1\",\"BadgeName\":\"00236\","
+    "\"Created\":1504474554,\"Modified\":1504474554}"
+    "],\"Leaderboards\":[]"
+    "}}";
+  rc_api_achievement_definition_t* achievement;
+
+  memset(&fetch_game_data_response, 0, sizeof(fetch_game_data_response));
+
+  ASSERT_NUM_EQUALS(rc_api_process_fetch_game_data_response(&fetch_game_data_response, server_response), RC_OK);
+  ASSERT_NUM_EQUALS(fetch_game_data_response.response.succeeded, 1);
+  ASSERT_PTR_NULL(fetch_game_data_response.response.error_message);
+  ASSERT_NUM_EQUALS(fetch_game_data_response.id, 20);
+  ASSERT_STR_EQUALS(fetch_game_data_response.title, "Another Amazing Game");
+  ASSERT_NUM_EQUALS(fetch_game_data_response.console_id, 19);
+  ASSERT_STR_EQUALS(fetch_game_data_response.image_name, "112233");
+  ASSERT_STR_EQUALS(fetch_game_data_response.rich_presence_script, "");
+  ASSERT_NUM_EQUALS(fetch_game_data_response.num_achievements, 4);
+  ASSERT_NUM_EQUALS(fetch_game_data_response.num_leaderboards, 0);
+
+  ASSERT_PTR_NOT_NULL(fetch_game_data_response.achievements);
+  achievement = fetch_game_data_response.achievements;
+
+  ASSERT_NUM_EQUALS(achievement->id, 5501);
+  ASSERT_STR_EQUALS(achievement->title, "Ach1");
+  ASSERT_STR_EQUALS(achievement->description, "Desc1");
+  ASSERT_NUM_EQUALS(achievement->category, RC_ACHIEVEMENT_CATEGORY_CORE);
+  ASSERT_NUM_EQUALS(achievement->points, 5);
+  ASSERT_STR_EQUALS(achievement->definition, "0=1");
+  ASSERT_STR_EQUALS(achievement->author, "User1");
+  ASSERT_STR_EQUALS(achievement->badge_name, "00234");
+  ASSERT_NUM_EQUALS(achievement->created, 1367266583);
+  ASSERT_NUM_EQUALS(achievement->updated, 1376929305);
+
+  ++achievement;
+  ASSERT_NUM_EQUALS(achievement->id, 5502);
+  ASSERT_STR_EQUALS(achievement->title, "Ach2");
+  ASSERT_STR_EQUALS(achievement->description, "Desc2");
+  ASSERT_NUM_EQUALS(achievement->category, RC_ACHIEVEMENT_CATEGORY_CORE);
+  ASSERT_NUM_EQUALS(achievement->points, 2);
+  ASSERT_STR_EQUALS(achievement->definition, "0=2");
+  ASSERT_STR_EQUALS(achievement->author, "");
+  ASSERT_STR_EQUALS(achievement->badge_name, "00235");
+  ASSERT_NUM_EQUALS(achievement->created, 1376970283);
+  ASSERT_NUM_EQUALS(achievement->updated, 1376970283);
+
+  ++achievement;
+  ASSERT_NUM_EQUALS(achievement->id, 5503);
+  ASSERT_STR_EQUALS(achievement->title, "Ach3");
+  ASSERT_STR_EQUALS(achievement->description, "Desc3");
+  ASSERT_NUM_EQUALS(achievement->category, RC_ACHIEVEMENT_CATEGORY_UNOFFICIAL);
+  ASSERT_NUM_EQUALS(achievement->points, 0);
+  ASSERT_STR_EQUALS(achievement->definition, "0=3");
+  ASSERT_STR_EQUALS(achievement->author, "");
+  ASSERT_STR_EQUALS(achievement->badge_name, "00236");
+  ASSERT_NUM_EQUALS(achievement->created, 1376969412);
+  ASSERT_NUM_EQUALS(achievement->updated, 1376969412);
+
+  ++achievement;
+  ASSERT_NUM_EQUALS(achievement->id, 5504);
+  ASSERT_STR_EQUALS(achievement->title, "Ach4");
+  ASSERT_STR_EQUALS(achievement->description, "Desc4");
+  ASSERT_NUM_EQUALS(achievement->category, RC_ACHIEVEMENT_CATEGORY_CORE);
+  ASSERT_NUM_EQUALS(achievement->points, 10);
+  ASSERT_STR_EQUALS(achievement->definition, "0=4");
+  ASSERT_STR_EQUALS(achievement->author, "User1");
+  ASSERT_STR_EQUALS(achievement->badge_name, "00236");
+  ASSERT_NUM_EQUALS(achievement->created, 1504474554);
+  ASSERT_NUM_EQUALS(achievement->updated, 1504474554);
+
+  rc_api_destroy_fetch_game_data_response(&fetch_game_data_response);
+}
+
 static void test_process_fetch_game_data_response_leaderboards() {
   rc_api_fetch_game_data_response_t fetch_game_data_response;
   const char* server_response = "{\"Success\":true,\"PatchData\":{"
@@ -716,6 +805,26 @@ static void test_init_award_achievement_request_no_achievement_id() {
   rc_api_destroy_request(&request);
 }
 
+static void test_init_award_achievement_request_delayed() {
+  rc_api_award_achievement_request_t award_achievement_request;
+  rc_api_request_t request;
+
+  memset(&award_achievement_request, 0, sizeof(award_achievement_request));
+  award_achievement_request.username = "Username";
+  award_achievement_request.api_token = "API_TOKEN";
+  award_achievement_request.achievement_id = 1234;
+  award_achievement_request.hardcore = 1;
+  award_achievement_request.game_hash = "ABCDEF0123456789";
+  award_achievement_request.seconds_since_unlock = 17;
+
+  ASSERT_NUM_EQUALS(rc_api_init_award_achievement_request(&request, &award_achievement_request), RC_OK);
+  ASSERT_STR_EQUALS(request.url, DOREQUEST_URL);
+  ASSERT_STR_EQUALS(request.post_data, "r=awardachievement&u=Username&t=API_TOKEN&a=1234&h=1&m=ABCDEF0123456789&o=17&v=b2326b09d61e9264eb5d3607d947317d");
+  ASSERT_STR_EQUALS(request.content_type, RC_CONTENT_TYPE_URLENCODED);
+
+  rc_api_destroy_request(&request);
+}
+
 static void test_process_award_achievement_response_success() {
   rc_api_award_achievement_response_t award_achievement_response;
   const char* server_response = "{\"Success\":true,\"Score\":119102,\"SoftcoreScore\":777,\"AchievementID\":56481,\"AchievementsRemaining\":11}";
@@ -1040,6 +1149,26 @@ static void test_init_submit_lboard_entry_request_no_leaderboard_id() {
   rc_api_destroy_request(&request);
 }
 
+static void test_init_submit_lboard_entry_request_delayed() {
+  rc_api_submit_lboard_entry_request_t submit_lboard_entry_request;
+  rc_api_request_t request;
+
+  memset(&submit_lboard_entry_request, 0, sizeof(submit_lboard_entry_request));
+  submit_lboard_entry_request.username = "Username";
+  submit_lboard_entry_request.api_token = "API_TOKEN";
+  submit_lboard_entry_request.leaderboard_id = 1234;
+  submit_lboard_entry_request.score = 10999;
+  submit_lboard_entry_request.game_hash = "ABCDEF0123456789";
+  submit_lboard_entry_request.seconds_since_completion = 33;
+
+  ASSERT_NUM_EQUALS(rc_api_init_submit_lboard_entry_request(&request, &submit_lboard_entry_request), RC_OK);
+  ASSERT_STR_EQUALS(request.url, DOREQUEST_URL);
+  ASSERT_STR_EQUALS(request.post_data, "r=submitlbentry&u=Username&t=API_TOKEN&i=1234&s=10999&m=ABCDEF0123456789&o=33&v=7971fc37cf38026f99dd4bae84360ac1");
+  ASSERT_STR_EQUALS(request.content_type, RC_CONTENT_TYPE_URLENCODED);
+
+  rc_api_destroy_request(&request);
+}
+
 static void test_process_submit_lb_entry_response_success() {
   rc_api_submit_lboard_entry_response_t submit_lb_entry_response;
   rc_api_lboard_entry_t* entry;
@@ -1148,6 +1277,7 @@ void test_rapi_runtime(void) {
   TEST(test_process_fetch_game_data_response_achievements);
   TEST(test_process_fetch_game_data_response_achievement_types);
   TEST(test_process_fetch_game_data_response_achievement_rarity);
+  TEST(test_process_fetch_game_data_response_achievement_null_author);
   TEST(test_process_fetch_game_data_response_leaderboards);
   TEST(test_process_fetch_game_data_response_rich_presence);
   TEST(test_process_fetch_game_data_response_rich_presence_null);
@@ -1169,6 +1299,7 @@ void test_rapi_runtime(void) {
   TEST(test_init_award_achievement_request_non_hardcore);
   TEST(test_init_award_achievement_request_no_hash);
   TEST(test_init_award_achievement_request_no_achievement_id);
+  TEST(test_init_award_achievement_request_delayed);
 
   TEST(test_process_award_achievement_response_success);
   TEST(test_process_award_achievement_response_hardcore_already_unlocked);
@@ -1188,6 +1319,7 @@ void test_rapi_runtime(void) {
   TEST(test_init_submit_lboard_entry_request_zero_value);
   TEST(test_init_submit_lboard_entry_request_negative_value);
   TEST(test_init_submit_lboard_entry_request_no_leaderboard_id);
+  TEST(test_init_submit_lboard_entry_request_delayed);
 
   TEST(test_process_submit_lb_entry_response_success);
   TEST(test_process_submit_lb_entry_response_no_entries);
