@@ -28,7 +28,7 @@ static int evaluate_lboard(rc_lboard_t* lboard, memory_t* memory, int* value) {
 }
 
 static void test_simple_leaderboard() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -80,7 +80,7 @@ static void test_simple_leaderboard() {
 }
 
 static void test_start_and_cancel_same_frame() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -117,7 +117,7 @@ static void test_start_and_cancel_same_frame() {
 }
 
 static void test_start_and_submit_same_frame() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -146,8 +146,45 @@ static void test_start_and_submit_same_frame() {
   ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_STARTED);
 }
 
+static void test_start_and_submit_same_frame_hitcount() {
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  memory_t memory;
+  rc_lboard_t* lboard;
+  char buffer[1024];
+  int value;
+
+  memory.ram = ram;
+  memory.size = sizeof(ram);
+
+  assert_parse_lboard(&lboard, buffer, "STA:0xH00=0::CAN:0=1::SUB:1=1::VAL:M:0xH02=52");
+  lboard->state = RC_LBOARD_STATE_ACTIVE;
+
+  /* start and submit are both true - should trigger. value logic is true, submit one hit */
+  ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_TRIGGERED);
+  ASSERT_NUM_EQUALS(value, 1);
+
+  /* disable start - leaderboard can activate */
+  ram[0] = 1;
+  ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_ACTIVE);
+
+  /* reactivate leaderboard - it should immediately submit again. value logic is still true, submit one hit */
+  ram[0] = 0;
+  ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_TRIGGERED);
+  ASSERT_NUM_EQUALS(value, 1);
+
+  /* disable start - leaderboard can activate */
+  ram[0] = 1;
+  ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_ACTIVE);
+
+  /* reactivate leaderboard - it should immediately submit again. value logic is not true, submit zero hits */
+  ram[2] = 55;
+  ram[0] = 0;
+  ASSERT_NUM_EQUALS(evaluate_lboard(lboard, &memory, &value), RC_LBOARD_STATE_TRIGGERED);
+  ASSERT_NUM_EQUALS(value, 0);
+}
+
 static void test_start_and_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -173,7 +210,7 @@ static void test_start_and_conditions() {
 }
 
 static void test_start_or_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -203,7 +240,7 @@ static void test_start_or_conditions() {
 }
 
 static void test_start_resets_value() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -254,7 +291,7 @@ static void test_start_resets_value() {
 }
 
 static void test_cancel_or_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -284,7 +321,7 @@ static void test_cancel_or_conditions() {
 }
 
 static void test_submit_and_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -310,7 +347,7 @@ static void test_submit_and_conditions() {
 }
 
 static void test_submit_or_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -340,7 +377,7 @@ static void test_submit_or_conditions() {
 }
 
 static void test_progress() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -363,7 +400,7 @@ static void test_progress() {
 }
 
 static void test_value_from_hitcount() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -424,7 +461,7 @@ static void test_value_from_hitcount() {
 }
 
 static void test_value_from_addhits() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -472,7 +509,7 @@ static void test_value_from_addhits() {
 
 static void test_value_from_float() {
   /* bytes 5-8 are the float value for pi */
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56, 0xDB, 0x0F, 0x49, 0x40};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56, 0xDB, 0x0F, 0x49, 0x40};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -505,7 +542,7 @@ static void test_value_from_float() {
 
 static void test_value_from_float_scaled() {
   /* bytes 5-8 are the float value for pi */
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56, 0xDB, 0x0F, 0x49, 0x40};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56, 0xDB, 0x0F, 0x49, 0x40};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -537,7 +574,7 @@ static void test_value_from_float_scaled() {
 }
 
 static void test_maximum_value_from_conditions() {
-  unsigned char ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
+  uint8_t ram[] = {0x00, 0x12, 0x34, 0xAB, 0x56};
   memory_t memory;
   rc_lboard_t* lboard;
   char buffer[1024];
@@ -629,6 +666,7 @@ void test_lboard(void) {
   TEST(test_simple_leaderboard);
   TEST(test_start_and_cancel_same_frame);
   TEST(test_start_and_submit_same_frame);
+  TEST(test_start_and_submit_same_frame_hitcount);
 
   TEST(test_start_and_conditions);
   TEST(test_start_or_conditions);
