@@ -36,6 +36,7 @@ static const char* flag_string(char type) {
     case RC_CONDITION_MEASURED: return "Measured ";
     case RC_CONDITION_ADD_SOURCE: return "AddSource ";
     case RC_CONDITION_SUB_SOURCE: return "SubSource ";
+    case RC_CONDITION_REMEMBER: return "Remember ";
     case RC_CONDITION_ADD_ADDRESS: return "AddAddress ";
     case RC_CONDITION_ADD_HITS: return "AddHits ";
     case RC_CONDITION_SUB_HITS: return "SubHits ";
@@ -56,6 +57,7 @@ static const char* type_string(char type) {
     case RC_OPERAND_PRIOR: return "Prior";
     case RC_OPERAND_BCD: return "BCD";
     case RC_OPERAND_INVERTED: return "Inverted";
+    case RC_OPERAND_RECALL: return "Recall";
     default: return "Unknown";
   }
 }
@@ -92,6 +94,9 @@ static const char* operator_string(char oper) {
     case RC_OPERATOR_XOR: return "^";
     case RC_OPERATOR_MULT: return "*";
     case RC_OPERATOR_DIV: return "/";
+    case RC_OPERATOR_MOD: return "%";
+    case RC_OPERATOR_ADD: return "+";
+    case RC_OPERATOR_SUB: return "-";
     case RC_OPERATOR_EQ: return "=";
     case RC_OPERATOR_NE: return "!=";
     case RC_OPERATOR_GE: return ">=";
